summaryrefslogtreecommitdiffstats
path: root/kandy/src/mobilegui.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kandy/src/mobilegui.cpp')
-rw-r--r--kandy/src/mobilegui.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kandy/src/mobilegui.cpp b/kandy/src/mobilegui.cpp
index 86f07514..fec40b7f 100644
--- a/kandy/src/mobilegui.cpp
+++ b/kandy/src/mobilegui.cpp
@@ -430,7 +430,7 @@ void MobileGui::writePhonebook()
void MobileGui::writePhonebookPostProcessing()
{
mLastWriteId = "";
- emit transientStatusMessage( i18n( "Wrote mobile phonebook." ) );
+ emit transienStatusMessage( i18n( "Wrote mobile phonebook." ) );
PushButton12->setEnabled( true );
setMobState( LOADED );
updateMobileBook();
@@ -640,7 +640,7 @@ void MobileGui::readKabc()
// Display KAB entries
updateKabBook();
- emit transientStatusMessage( i18n( "Read KDE address book." ) );
+ emit transienStatusMessage( i18n( "Read KDE address book." ) );
setKabState( LOADED );
}
@@ -922,7 +922,7 @@ void MobileGui::writeKabc()
*fields = TQStringList::split( ',', name );
if ( fields->count() > 1 ) {
// Name string contains comma separated entry so that we
// need to build family and given names out of them.
TQString givenName = "";
@@ -933,7 +933,7 @@ void MobileGui::writeKabc()
givenName += stripWhiteSpaces( (*fields)[ i ] ) + " ";
entry.setGivenName( stripWhiteSpaces( givenName ) );
} else
// Name string contains only one string without comma.
entry.setFamilyName( stripWhiteSpaces( name ) );
entry.insertPhoneNumber( KABC::PhoneNumber( phoneNumber, phoneType ) );
@@ -948,7 +948,7 @@ void MobileGui::writeKabc()
addressBook->save( ticket );
- emit transientStatusMessage( i18n( "Wrote KDE address book." ) );
+ emit transienStatusMessage( i18n( "Wrote KDE address book." ) );
setKabState( LOADED );
}
@@ -1159,7 +1159,7 @@ void MobileGui::fillPhonebook( ATCommand *cmd )
// Display mobile entries
updateMobileBook();
- emit transientStatusMessage(i18n("Read mobile phonebook."));
+ emit transienStatusMessage(i18n("Read mobile phonebook."));
emit phonebookRead();
setMobState( LOADED );
@@ -1398,7 +1398,7 @@ void MobileGui::mergePhonebooks()
updateKabBook();
updateMobileBook();
- emit transientStatusMessage( i18n( "Synced phonebooks." ) );
+ emit transienStatusMessage( i18n( "Synced phonebooks." ) );
PushButton8_3->setEnabled( true );
}
@@ -1561,7 +1561,7 @@ void MobileGui::warnKabState( ABState newState )
{
if ( ( mKabState == MODIFIED ) && ( newState != MODIFIED ) ) {
TQString text = "<qt><b>" + i18n( "Warning" ) + "</b><br>";
- text += i18n( "The KDE address book contains unsaved changes." ) +
+ text += i18n( "The KDE address book tqcontains unsaved changes." ) +
"<br></qt>";
TQMessageBox *msg = new TQMessageBox( i18n( "Unsaved Changes" ), text,
@@ -1646,7 +1646,7 @@ bool MobileGui::warnMobState( ABState newState )
if ( ( mMobState == MODIFIED ) && ( newState != MODIFIED ) )
{
TQString text = "<qt><b>" + i18n( "Warning" ) + "</b><br>";
- text += i18n( "The mobile phone book contains unsaved changes." ) +
+ text += i18n( "The mobile phone book tqcontains unsaved changes." ) +
"<br></qt>";
TQMessageBox *msg = new TQMessageBox( i18n( "Unsaved Changes" ), text,
@@ -922,7 +922,7 @@ void MobileGui::writeKabc()
*fields = TQStringList::split( ',', name );
if ( fields->count() > 1 ) {
- // Name string contains comma separated entry so that we
+ // Name string tqcontains comma separated entry so that we
// need to build family and given names out of them.
TQString givenName = "";
@@ -933,7 +933,7 @@ void MobileGui::writeKabc()
entry.setGivenName( stripWhiteSpaces( givenName ) );
} else
- // Name string contains only one string without comma.
+ // Name string tqcontains only one string without comma.
entry.setFamilyName( stripWhiteSpaces( name ) );
entry.insertPhoneNumber( KABC::PhoneNumber( phoneNumber, phoneType ) );